import { useState, useEffect } from "react";
import useMediaQuery from "@mui/material/useMediaQuery";
import { useTheme } from "@mui/material/styles";
import Button from "@mui/material/Button";
import DialogTitle from "@mui/material/DialogTitle";
import DialogContent from "@mui/material/DialogContent";
import DialogActions from "@mui/material/DialogActions";
import Dialog from "@mui/material/Dialog";
import Toolbar from "@mui/material/Toolbar";

const textFileTypes = ["properties", "txt", "yaml", "yml", "json", "env"];
const imageFileTypes = ["png", "jpeg", "jpg"];

export const supportedFileTypes = [...textFileTypes, ...imageFileTypes];

export function useFilePreview(isOpen = false) {
  const [open, setOpen] = useState(isOpen);
  const dialogToggle = () => setOpen(!open);
  return [open, dialogToggle];
}

function TextPreview(props) {
  const { fileText } = props;
  return <div style={{ whiteSpace: "break-spaces" }}>{fileText}</div>;
}

export default function FilePreview(props) {
  const [fileText, setFileText] = useState();
  const theme = useTheme();
  const fullScreen = useMediaQuery(theme.breakpoints.down("md"));

  const { previewData, open, dialogToggle } = props;
  const { fileData, name } = previewData ?? {};
  const ext = name ? name.split(".").pop() : null;
  const isTextFile = textFileTypes.includes(ext);

  async function onPreviewChange() {
    if (isTextFile) setFileText(await fileData.text());
  }

  useEffect(() => {
    onPreviewChange();
  }, [fileData]);

  return (
    <Dialog
      sx={
        fullScreen
          ? {}
          : {
              "& .mcl-MuiDialog-paper": {
                width: "100%",
                maxHeight: 525,
                maxWidth: "80%",
              },
            }
      }
      maxWidth="xs"
      open={open}
      fullScreen={fullScreen}
    >
      <Toolbar sx={{ display: { sm: "none" } }} />
      <DialogTitle>{name}</DialogTitle>
      <DialogContent>
        <TextPreview fileText={fileText} />
      </DialogContent>
      <DialogActions>
        <Button autoFocus onClick={dialogToggle}>
          Close
        </Button>
      </DialogActions>
    </Dialog>
  );
}
